# -*- coding: utf-8 -*-
"""
KM3NeT Data Definitions v2.1.0-1-ga85a9c1
https://git.km3net.de/common/km3net-dataformat
"""

# w2list_gseagen
data = dict(
    W2LIST_GSEAGEN_PS=0,
    W2LIST_GSEAGEN_EG=1,
    W2LIST_GSEAGEN_XSEC_MEAN=2,
    W2LIST_GSEAGEN_COLUMN_DEPTH=3,
    W2LIST_GSEAGEN_P_EARTH=4,
    W2LIST_GSEAGEN_WATER_INT_LEN=5,
    W2LIST_GSEAGEN_P_SCALE=6,
    W2LIST_GSEAGEN_BX=7,
    W2LIST_GSEAGEN_BY=8,
    W2LIST_GSEAGEN_ICHAN=9,
    W2LIST_GSEAGEN_CC=10,
    W2LIST_GSEAGEN_DISTAMAX=11,
    W2LIST_GSEAGEN_WATERXSEC=12,
    W2LIST_GSEAGEN_XSEC=13,
    W2LIST_GSEAGEN_DXSEC=14,
    W2LIST_GSEAGEN_TARGETA=15,
    W2LIST_GSEAGEN_TARGETZ=16,
    W2LIST_GSEAGEN_VERINCAN=17,
    W2LIST_GSEAGEN_LEPINCAN=18,
    W2LIST_GSEAGEN_N_RETRIES=19,
    W2LIST_GSEAGEN_CUSTOM_YAW=20,
    W2LIST_GSEAGEN_CUSTOM_PITCH=21,
    W2LIST_GSEAGEN_CUSTOM_ROLL=22,
)
