# -*- coding: utf-8 -*-
"""
KM3NeT Data Definitions v2.1.0-1-ga85a9c1
https://git.km3net.de/common/km3net-dataformat
"""

# pmt_status
data = dict(
    PMT_DISABLE= 0,
    HIGH_RATE_VETO_DISABLE= 1,
    FIFO_FULL_DISABLE= 2,
    UDP_COUNTER_DISABLE= 3,
    UDP_TRAILER_DISABLE= 4,
    OUT_OF_SYNC= 5,
)
